<a href="http://pythoninchemistry.org/pylj"><img src="https://github.com/arm61/pylj/blob/master/logo/logo.png?raw=true" width= "60%"/></a>

## Visit the [pylj](http://pythoninchemistry.org/pylj) webpage for more information about pylj.

To build from source:

```python

pip install -r requirements.txt

python setup.py build

python setup.py install

python setup.py test

```
Check out our publication in the [Journal of Open Source Education](http://jose.theoj.org/papers/58daa1a1a564dc8e0f99ffcdae20eb1d) to find out more about pylj.

Be aware! pylj runs within a [Jupyter notebook](http://jupyter.org/), and therefore requires this to run. We advise installing [anaconda python](https://anaconda.org/) as this includes many required libraries as well as the Jupyter notebooks framework.

If you need any help using pylj contact arm61 in the [pylj/HELP gitter chatroom](https://gitter.im/pylj/HELP).

Check out some [examples](https://github.com/arm61/pylj/tree/master/examples) of how pylj can be used in undergraduate teaching exercises.

## Badges

<table>
  <tr>
    <td>JOSE DOI</td>
    <td>
      <a href="http://jose.theoj.org/papers/58daa1a1a564dc8e0f99ffcdae20eb1d">
      <img src="http://jose.theoj.org/papers/58daa1a1a564dc8e0f99ffcdae20eb1d/status.svg" alt="status" />
      </a>
    </td>
  </tr>
  <tr>
    <td>Latest Release</td>
    <td>
      <a href="https://badge.fury.io/py/pylj">
      <img src="https://badge.fury.io/py/pylj.svg" alt="PyPi version" />
      </a>
    </td>
  </tr>
  <tr>
    <td></td>
    <td>
      <a href="https://zenodo.org/badge/latestdoi/119863480">
      <img src="https://zenodo.org/badge/119863480.svg" alt="DOI" />
      </a>
    </td>
  </tr>
  <tr>
    <td>Documentation</td>
    <td>
      <a href="http://pylj.readthedocs.io/en/latest/?badge=latest">
      <img src="https://readthedocs.org/projects/pylj/badge/?version=latest" alt="Documentation Status" />
      </a>
    </td>
  </tr>
  <tr>
    <td>License</td>
    <td>
      <a href="https://opensource.org/licenses/MIT">
      <img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="License MIT" />
      </a>
    </td>
  </tr>
  <tr>
    <td>Build Status</td>
    <td>
      <a href="https://github.com/arm61/pylj/actions">
        <img src="https://github.com/arm61/pylj/actions/workflows/ci.yml/badge.svg" alt="Build Status" />
      </a>
  </tr>
  <tr>
    <td>Coverage Status</td>
    <td>
      <a href="https://codeclimate.com/github/arm61/pylj/test_coverage">
        <img src="https://api.codeclimate.com/v1/badges/770882d2010bb099b241/test_coverage" />
      </a>
    </td>
  </tr>
  <tr>
    <td>Gitter</td>
    <td>
      <a href="https://gitter.im/pylj/Lobby#">
      <img src="https://badges.gitter.im/gitterHQ/gitter.png" alt="Gitter chat" />
      </a>
    </td>
  </tr>
</table>
